@@ -1,9 +1,9 @@
 import pkg_resources
 
-from . import ipd_comps, source_params
-from ._contour import tabulate_density
-from .ipd_models import model_registry
-from .zodipy import Zodipy
+from zodipy import comps, source_params
+from zodipy._contour import tabulate_density
+from zodipy.model_registry import model_registry
+from zodipy.zodipy import Zodipy
 
 try:
     __version__ = pkg_resources.get_distribution(__name__).version
@@ -13,7 +13,7 @@ except pkg_resources.DistributionNotFound:  # pragma: no cover
 __all__ = (
     "Zodipy",
     "model_registry",
-    "ipd_comps",
+    "comps",
     "source_params",
     "tabulate_density",
 )
